"""Microsoft Word review tools (comments, markup, etc.) with Python."""

from docxrev.docxrev import *  # noqa: F401, F403
